==> phpwiki-1.2.2.tbz: www/data-dist/phpwiki/locale/de/LC_MESSAGES/phpwiki.php <==
<?php

$locale["You entered an invalid login or password."] =
   "Du hast ein ungltiges Login oder Passwort eingegeben.";
$locale["You are about to remove '%s' permanently!"] =
   "Du bist im Begriff '%s' permanent zu lschen!";
$locale["Click %shere%s to remove the page now."] =
   "Klicke %shier%s um die Seite jetzt zu lschen.";
$locale["Otherwise press the \"Back\" button of your browser."] =
   "Anderenfalls bentze die \"Zurck\" Funktion deines Browsers.";
$locale["Function not yet implemented."] =
   "Funktion noch nicht implementiert.";
$locale["Remove page"] =
   "Seite lschen";
$locale["Removed page '%s' succesfully."] =
   "Seite '%s' erfolgreich gelscht.";
$locale["templates/browse.html"] =
   "locale/de/templates/browse.html";
$locale["templates/editpage.html"] =
   "locale/de/templates/editpage.html";
$locale["templates/editlinks.html"] =
   "locale/de/templates/editlinks.html";
$locale["templates/message.html"] =
   "locale/de/templates/message.html";
$locale["./pgsrc"] =
   "locale/de/pgsrc";
$locale["Current page:"] =
   "Aktuelle Seite:";
$locale["version %s"] =
   "Version %s";
$locale["last modified on %s"] =
   "zuletzt verndert am %s";
$locale["by %s"] =
   "von %s";
$locale["None"] =
   "Keine";
$locale["Archived page:"] =
   "Archivierte Seite:";
$locale["Versions are identical"] =
   "Versionen sind identisch";
$locale["Diff of %s."] =
   "Diff von %s.";
$locale["FrontPage"] =
   "StartSeite";
$locale["Describe %s here."] =
   "Beschreibe %s hier.";
$locale["Copy of %s"] =
   "Kopie von %s";
$locale["No page name passed into editpage!"] =
   "Kein Seitenname an EditierSeite bergeben!";
$locale["This page has been locked by the administrator and cannot be edited."] =
   "Diese Seite wurde vom Administrator gesperrt und kann nicht editiert werden.";
$locale["Sorry for the inconvenience."] =
   "Entschuldigung fr die Unannehmlichkeiten.";
$locale["Problem while editing %s"] =
   "Problem whrend dem Editieren von %s";
$locale["Searching for \"%s\" ....."] =
   "Suche nach \"%s\" .....";
$locale["%d matches found in %d pages."] =
   "%d Treffer in %d Seiten.";
$locale["Full Text Search Results"] =
   "Volltext-Suchresultate";
$locale["Cannot establish connection to database, giving up."] =
   "Kann Verbindung zu Datenbank nicht aufbauen - Abbruch.";
$locale["Error message: %s"] =
   "Fehlermeldung: %s";
$locale["Cannot open database %s, giving up."] =
   "Kann Datenbank %s nicht ffnen - Abbruch.";
$locale["Insert/update failed: %s"] =
   "Einfgen/Verndern fehlgeschlagen: %s";
$locale["Delete on %s failed: %s"] =
   "Lschen in %s fehlgeschlagen: %s";
$locale["Insert into %s failed: %s"] =
   "Einfgen in %s fehlgeschlagen: %s";
$locale["MySQL error: %s"] =
   "MySQL Fehler: %s";
$locale["Error writing page '%s'"] =
   "Fehler beim Schreiben der Seite '%s'";
$locale["Cannot delete '%s' from table '%s'"] =
   "Kann nicht '%s' aus Tabelle '%s' lschen";
$locale["Enter a page name"] =
   "Seitenname eingeben";
$locale["Go"] =
   "Los";
$locale["Show the page source and references"] =
   "Zeige den Seitenquelltext und die Verweise";
$locale["PageInfo"] =
   "SeitenInfo";
$locale["Page name '%s' is not in the database"] =
   "Seite '%s' ist nicht in der Datenbank";
$locale["Current version"] =
   "Aktuelle Seite:";
$locale["Archived version"] =
   "Archivierte Seite:";
$locale["RecentChanges"] =
   "FrischeSeiten";
$locale["PhpWiki is unable to save your changes, because another user edited and saved the page while you were editing the page too. If saving proceeded now changes from the previous author would be lost."] =
   "PhpWiki kann deine Vernderungen nicht speichern, da ein andererBentzer die Seite verndert und gespeichert hat, whrend du diese Seiteeditiert hast. Wenn die Seite jetzt gespeichert werden wrde, dann wrdendie Vernderungen des anderen Bentzers verloren gehen.";
$locale["In order to recover from this situation follow these steps:"] =
   "Um diese Situation zu korrigieren folge bitte den folgenden Schritten:";
$locale["Use your browser's <b>Back</b> button to go back to the edit page."] =
   "Bentze die <b>Zurck</b> Funktion deines Browsers um zur Editierseitezu gelangen.";
$locale["Copy your changes to the clipboard or to another temporary place (e.g. text editor)."] =
   "Kopiere deine Vernderungen in die Zwischenablage oder an einen anderentemporren Platz (z.B. einen Texteditor)";
$locale["<b>Reload</b> the page. You should now see the most current version of the page. Your changes are no longer there."] =
   "<b>Aktualisiere</b> die Seite. Du solltest jetzt die neueste Versionder Seite sehen. Deine Vernderungen sind verschwunden.";
$locale["Make changes to the file again. Paste your additions from the clipboard (or text editor)."] =
   "Editiere die Seite erneut. Kopiere deine Vernderungen aus derZwischenablage (oder aus dem Texteditor)";
$locale["Press <b>Save</b> again."] =
   "Drcke nochmal <b>Speichern</b>";
$locale["Problem while updating %s"] =
   "Problem whrend dem Editieren von %s";
$locale["Thank you for editing %s."] =
   "Danke fr das Editieren von %s.";
$locale["Your careful attention to detail is much appreciated."] =
   "Deine besondere Aufmerksamkeit fr Details wird sehr geschtzt.";
$locale["%d pages match your query."] =
   "%d Seiten wurden gefunden.";
$locale["Title Search Results"] =
   "Volltext-Suchresultate";
$locale["Inserting page %s, version %s from %s"] =
   "Fge Seite %s ein, Version %s vom %s";
$locale["WikiFatalError"] =
   "FatalerWikiFehler";
$locale["Search"] =
   "Suche";
$locale["Nesting depth exceeded in SetHTMLOutputMode"] =
   "Interner Fehler: Stackgrenze in SetHTMLOutputMode berschritten.";
$locale["%d best incoming links:"] =
   "Die %d besten hereinkommenden Links:";
$locale["%d best outgoing links:"] =
   "Die %d besten hinausgehenden Links:";
$locale["%d most popular nearby:"] =
   "Die %d meistbesuchten Seiten in der Nhe:";

;?>

==> phpwiki-1.2.10_1.tbz: www/data-dist/phpwiki/locale/de/LC_MESSAGES/phpwiki.php <==
<?php

$locale["Set the administrator account and password first.\n"] =
   "Setze zuerst den Administrator Loginname und Passwort.\n";
$locale["You entered an invalid login or password."] =
   "Du hast ein ungltiges Login oder Passwort eingegeben.";
$locale["You are about to remove '%s' permanently!"] =
   "Du bist im Begriff '%s' permanent zu lschen!";
$locale["Click %shere%s to remove the page now."] =
   "Klicke %shier%s um die Seite jetzt zu lschen.";
$locale["Otherwise press the \"Back\" button of your browser."] =
   "Anderenfalls bentze die \"Zurck\" Funktion deines Browsers.";
$locale["Function not yet implemented."] =
   "Funktion noch nicht implementiert.";
$locale["Remove page"] =
   "Seite lschen";
$locale["Removed page '%s' succesfully."] =
   "Seite '%s' erfolgreich gelscht.";
$locale["templates/browse.html"] =
   "locale/de/templates/browse.html";
$locale["templates/editpage.html"] =
   "locale/de/templates/editpage.html";
$locale["templates/editlinks.html"] =
   "locale/de/templates/editlinks.html";
$locale["templates/message.html"] =
   "locale/de/templates/message.html";
$locale["./pgsrc"] =
   "locale/de/pgsrc";
$locale["'%s': corrupt file"] =
   "'%s': korrupte Datei";
$locale["%s: bad data<br>\n"] =
   "%s: falsche Daten<br>\n";
$locale["%s: Bad filename in database<br>\n"] =
   "%s: Ungltiger Dateiname in Datenbank<br>\n";
$locale["WikiDiff::_check: failed"] =
   "WikiDiff::_check: Fehler";
$locale["Current page:"] =
   "Aktuelle Seite:";
$locale["version %s"] =
   "Version %s";
$locale["last modified on %s"] =
   "zuletzt verndert am %s";
$locale["by %s"] =
   "von %s";
$locale["None"] =
   "Keine";
$locale["Archived page:"] =
   "Archivierte Seite:";
$locale["Versions are identical"] =
   "Versionen sind identisch";
$locale["Diff of %s."] =
   "Diff von %s.";
$locale["FrontPage"] =
   "StartSeite";
$locale["Describe %s here."] =
   "Beschreibe %s hier.";
$locale["Copy of %s"] =
   "Kopie von %s";
$locale["No page name passed into editpage!"] =
   "Kein Seitenname an EditierSeite bergeben!";
$locale["This page has been locked by the administrator and cannot be edited."] =
   "Diese Seite wurde vom Administrator gesperrt und kann nicht editiert werden.";
$locale["Sorry for the inconvenience."] =
   "Entschuldigung fr die Unannehmlichkeiten.";
$locale["Problem while editing %s"] =
   "Problem whrend dem Editieren von %s";
$locale["Searching for \"%s\" ....."] =
   "Suche nach \"%s\" .....";
$locale["(You entered an empty search string)"] =
   "(Sie haben einen leeren Suchtext eingegeben)";
$locale["%d matches found in %d pages."] =
   "%d Treffer in %d Seiten.";
$locale["Full Text Search Results"] =
   "Volltext-Suchresultate";
$locale["Cannot establish connection to database, giving up."] =
   "Kann Verbindung zu Datenbank nicht aufbauen - Abbruch.";
$locale["Error message: %s"] =
   "Fehlermeldung: %s";
$locale["Cannot open database %s, giving up."] =
   "Kann Datenbank %s nicht ffnen - Abbruch.";
$locale["Insert/update to table 'wiki' failed: %s"] =
   "Einfgen/Verndern in Tabelle 'wiki' fehlgeschlagen: %s";
$locale["Delete on %s failed: %s"] =
   "Lschen in %s fehlgeschlagen: %s";
$locale["Insert into %s failed: %s"] =
   "Einfgen in %s fehlgeschlagen: %s";
$locale["Insert/update into table 'archive' failed: %s"] =
   "Einfgen/Verndern in Tabelle 'archive' fehlgeschlagen: %s";
$locale["MSSQL error: %s"] =
   "MSSQL Fehler: %s";
$locale["Insert/Update failed: %s"] =
   "Einfgen/Verndern fehlgeschlagen: %s";
$locale["Cannot delete '%s' from table '%s'"] =
   "Kann nicht '%s' aus Tabelle '%s' lschen";
$locale["MySQL error: %s"] =
   "MySQL Fehler: %s";
$locale["Error writing page '%s'"] =
   "Fehler beim Schreiben der Seite '%s'";
$locale["Enter a page name"] =
   "Seitenname eingeben";
$locale["Go"] =
   "Los";
$locale["Show the page source and references"] =
   "Zeige den Seitenquelltext und die Verweise";
$locale["PageInfo"] =
   "SeitenInfo";
$locale["Page name '%s' is not in the database"] =
   "Seite '%s' ist nicht in der Datenbank";
$locale["Current version"] =
   "Aktuelle Version";
$locale["Archived version"] =
   "Archivierte Version";
$locale["RecentChanges"] =
   "FrischeSeiten";
$locale["PhpWiki is unable to save your changes, because another user edited and saved the page while you were editing the page too. If saving proceeded now changes from the previous author would be lost."] =
   "PhpWiki kann deine Vernderungen nicht speichern, da ein andererBentzer die Seite verndert und gespeichert hat, whrend du diese Seiteeditiert hast. Wenn die Seite jetzt gespeichert werden wrde, dann wrdendie Vernderungen des anderen Bentzers verloren gehen.";
$locale["In order to recover from this situation follow these steps:"] =
   "Um diese Situation zu korrigieren folge bitte den folgenden Schritten:";
$locale["Use your browser's <b>Back</b> button to go back to the edit page."] =
   "Bentze die <b>Zurck</b> Funktion deines Browsers um zur Editierseitezu gelangen.";
$locale["Copy your changes to the clipboard or to another temporary place (e.g. text editor)."] =
   "Kopiere deine Vernderungen in die Zwischenablage oder an einen anderentemporren Platz (z.B. einen Texteditor)";
$locale["<b>Reload</b> the page. You should now see the most current version of the page. Your changes are no longer there."] =
   "<b>Aktualisiere</b> die Seite. Du solltest jetzt die neueste Versionder Seite sehen. Deine Vernderungen sind verschwunden.";
$locale["Make changes to the file again. Paste your additions from the clipboard (or text editor)."] =
   "Editiere die Seite erneut. Kopiere deine Vernderungen aus derZwischenablage (oder aus dem Texteditor)";
$locale["Press <b>Save</b> again."] =
   "Drcke nochmal <b>Speichern</b>";
$locale["Problem while updating %s"] =
   "Problem whrend dem Speichern von %s";
$locale["Thank you for editing %s."] =
   "Danke fr das Editieren von %s.";
$locale["Your careful attention to detail is much appreciated."] =
   "Deine besondere Aufmerksamkeit fr Details wird sehr geschtzt.";
$locale["%d pages match your query."] =
   "%d Seiten wurden gefunden.";
$locale["Title Search Results"] =
   "Volltext-Suchresultate";
$locale["Inserting page %s, version %s from %s"] =
   "Fge Seite %s ein, Version %s vom %s";
$locale["WikiFatalError"] =
   "FatalerWikiFehler";
$locale["Search"] =
   "Suche";
$locale["%d best incoming links:"] =
   "Die %d besten hereinkommenden Links:";
$locale["%d best outgoing links:"] =
   "Die %d besten hinausgehenden Links:";
$locale["%d most popular nearby:"] =
   "Die %d meistbesuchten Seiten in der Nhe:";

;?>
